%define anolis_release 2

%bcond_without lmdb
%bcond_without python3

%global tdb_version 1.4.8
%global tevent_version 0.14.1
%global talloc_version 2.3.3

Name:       libldb
Version:    2.7.2
Release:    %{anolis_release}%{?dist}
License:    LGPLv3+
Summary:    LDAP-like embedded database
URL:        http://ldb.samba.org/
Source0:    https://www.samba.org/ftp/ldb/ldb-%{version}.tar.gz

BuildRequires: make gcc gnupg2
BuildRequires: docbook-style-xsl libxslt doxygen pkgconfig(popt)
BuildRequires: pkgconfig(talloc) >= %{talloc_version} pkgconfig(tdb) >= %{tdb_version}
BuildRequires: pkgconfig(ldap) pkgconfig(cmocka) pkgconfig(tevent) >= %{tevent_version}
%if %{with python3}
BuildRequires: python3-tevent pkgconfig(python3) python3-talloc-devel python3-tdb
%endif
%if %{with lmdb}
BuildRequires: pkgconfig(lmdb) >= 0.9.16
%endif

Requires: libtdb >= %{tdb_version} libtevent >= %{tevent_version} libtalloc >= %{talloc_version}

Obsoletes: pyldb < 1.1.26-2
Obsoletes: python2-ldb < 2.0.5-1
Obsoletes: python2-ldb-devel < 2.0.5-1
Provides: bundled(libreplace)

%description
ldb is a LDAP-like embedded database. It is not at all LDAP standards compliant, 
so if you want a standards compliant database then please see the excellent OpenLDAP project.

What ldb does is provide a fast database with an LDAP-like API designed to be used within an 
application. In some ways it can be seen as a intermediate solution between key-value pair 
databases and a real LDAP database.

ldb is the database engine used in Samba4.

%package devel
Summary: Developer tools for the LDB library
Requires: pkgconfig(tevent) >= %{tevent_version} %{name} = %{version}-%{release}
Requires: pkgconfig(tdb) >= %{tdb_version} pkgconfig(talloc) >= %{talloc_version}

%description devel
Header files needed to develop programs that link against the LDB library.

%package -n ldb-tools
Summary: Tools to manage LDB files
Requires: %{name} = %{version}-%{release}

%description -n ldb-tools
A package that contains utilities for working with ldb, an LDAP-like embedded 
database built on top of TDB. It provides a fast database with an LDAP-like 
API designed to be used within an application. In some ways it can be seen as 
an intermediate solution between key-value pair databases and a real LDAP database

%package -n python-ldb-devel-common
Summary: Common development files for the Python bindings for the LDB library

Provides: pyldb-devel = %{version}-%{release}
%{?python_provide:%python_provide python2-ldb-devel}

%description -n python-ldb-devel-common
Development files for the Python bindings for the LDB library.
This package includes files that aren't specific to a Python version'.

%if %{with python3}
%package -n python3-ldb
Summary: Python bindings for the LDB library
Requires: %{name} = %{version}-%{release}
Requires: python3-tdb >= %{tdb_version}

%{?python_provide:%python_provide python3-ldb}

%description -n python3-ldb
Python bindings for the LDB library

%package -n python3-ldb-devel
Summary: Development files for the Python bindings for the LDB library
Requires: python-ldb-devel-common = %{version}-%{release}
Requires: python3-ldb = %{version}-%{release}

%{?python_provide:%python_provide python3-ldb-devel}

%description -n python3-ldb-devel
Development files for the Python bindings for the LDB library
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n ldb-%{version}

%build
export python_LDFLAGS=""
%configure --disable-rpath \
           --disable-rpath-install \
           --bundled-libraries=NONE \
           --builtin-libraries=replace \
           --with-modulesdir=%{_libdir}/ldb/modules \
%if %{without lmdb}
           --without-ldb-lmdb \
%endif
           --with-privatelibdir=%{_libdir}/ldb

%make_build
doxygen Doxyfile

%check
%if %{with lmdb}
%make_build check
%endif

%install
%make_install

# Install API docs
cp -a apidocs/man/* %{buildroot}/%{_mandir}
rm -f %{buildroot}/%{_mandir}/man3/_*

%generate_compatibility_deps

%files
%dir %{_libdir}/ldb
%{_libdir}/libldb.so.*
%{_libdir}/ldb/libldb-key-value.so
%{_libdir}/ldb/libldb-tdb-err-map.so
%{_libdir}/ldb/libldb-tdb-int.so
%dir %{abidir}
%{abidir}/libldb.dump
%{abidir}/libldb-key-value.dump
%{abidir}/libldb-tdb-err-map.dump
%{abidir}/libldb-tdb-int.dump
%if %{with lmdb}
%{_libdir}/ldb/libldb-mdb-int.so
%{abidir}/libldb-mdb-int.dump
%endif
%dir %{_libdir}/ldb/modules
%dir %{_libdir}/ldb/modules/ldb
%{_libdir}/ldb/modules/ldb/*.so
%{abidir}/mdb.dump
%{abidir}/asq.dump
%{abidir}/ldap.dump
%{abidir}/ldb.dump
%{abidir}/paged_searches.dump
%{abidir}/rdn_name.dump
%{abidir}/sample.dump
%{abidir}/server_sort.dump
%{abidir}/skel.dump
%{abidir}/tdb.dump

%files devel
%{_includedir}/ldb_module.h
%{_includedir}/ldb_handlers.h
%{_includedir}/ldb_errors.h
%{_includedir}/ldb_version.h
%{_includedir}/ldb.h
%{_libdir}/libldb.so
%{_libdir}/pkgconfig/ldb.pc
%{_mandir}/man3/ldb*
%{_mandir}/man3/ldif*

%files -n ldb-tools
%{_bindir}/ldbadd
%{_bindir}/ldbdel
%{_bindir}/ldbedit
%{_bindir}/ldbmodify
%{_bindir}/ldbrename
%{_bindir}/ldbsearch
%{_libdir}/ldb/libldb-cmdline.so
%{abidir}/libldb-cmdline.dump
%{_mandir}/man1/ldbadd.1.*
%{_mandir}/man1/ldbdel.1.*
%{_mandir}/man1/ldbedit.1.*
%{_mandir}/man1/ldbmodify.1.*
%{_mandir}/man1/ldbrename.1.*
%{_mandir}/man1/ldbsearch.1.*

%files -n python-ldb-devel-common
%{_includedir}/pyldb.h
%{_mandir}/man*/Py*

%if %{with python3}
%files -n python3-ldb
%{python3_sitearch}/ldb.cpython-*.so
%{_libdir}/libpyldb-util.cpython-*.so.2*
%{abidir}/ldb.cpython-*.dump
%{abidir}/libpyldb-util.cpython-*.dump
%{python3_sitearch}/_ldb_text.py
%{python3_sitearch}/__pycache__/_ldb_text.cpython-*.py*

%files -n python3-ldb-devel
%{_libdir}/libpyldb-util.cpython-*.so
%{_libdir}/pkgconfig/pyldb-util.cpython-*.pc
%endif

%files doc
%doc README_gcov.txt

%changelog
* Thu Apr 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 2.7.2-2
- Optimize the spec file

* Thu Mar 30 2023 Funda Wang <fundawang@yeah.net> - 2.7.2-1
- New version 2.7.2

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.7.1-2
- Del Specific Fields

* Wed Mar 8 2023 Funda Wang <fundawang@yeah.net> - 2.7.1-1
- New version 2.7.1

* Sun Oct 30 2022 Funda Wang <fundawang@yeah.net> - 2.6.1-1
- New version 2.6.1

* Tue Oct 25 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.5.0-2
- optimise spec file

* Wed Mar 09 2022 pangqing <pangqing@uniontech.com> - 2.5.0-1 
- Init for anolisOS 23

